# langchain-robocorp

| Note: this package is deprecated in favor of the renamed `langchain-sema4` package ([repo](https://github.com/langchain-ai/langchain-sema4), [package](https://pypi.org/project/langchain-sema4/)). |
|-|

This package contains the LangChain integrations for [Robocorp Action Server](https://github.com/robocorp/robocorp).
Action Server enables an agent to execute actions in the real world. 

## Installation

```bash
pip install -U langchain-robocorp
```

## Action Server Toolkit

See [ActionServerToolkit](https://python.langchain.com/docs/integrations/tools/robocorp) for detailed documentation.
